==> cscec5b-ecxj-impl-3.0.0-20230403.024840-5-sources.jar: com/ejianc/business/ecxj/bean/CompareEntity.java <==
package com.ejianc.business.ecxj.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 比选报价
 * 
 * @author generator
 * 
 */
 @TableName("ejc_ecxj_compare")
public class CompareEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_source_id")
    private String projectSourceId; // 项目来源id
    @TableField(value="crop_id")
    private Long cropId; // 项目所属组织id
    @TableField(value="crop_name")
    private String cropName; // 所属公司
    @TableField(value="crop_source_id")
    private String cropSourceId; // 项目所属组织来源id
    @TableField(value="real_corp_id")
    private Long realCorpId; // NC所属组织ID
    @TableField(value="real_nc_corp")
    private String realNcCorp; // NC所属组织PK
    @TableField(value="real_corp_name")
    private String realCorpName; // NC所属组织名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_source_id")
    private String orgSourceId; // 组织来源id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="submit_deadline")
    private Date submitDeadline; // 填报截止日期
    @TableField(value="compare_time")
    private Date compareTime; // 比选时间
    @TableField(value="setting_id")
    private Long settingId; // 引用的设置类型Id
    @TableField(value="tender_id")
    private Long tenderId; // 云筑招标Id
    @TableField(value="tender_no")
    private String tenderNo; // 云筑招标编号
    @TableField(value="tender_name")
    private String tenderName; // 云筑招标名称
    @TableField(value="notification")
    private String notification; // 通知内容
    @TableField(value="win_supplier_id")
    private String winSupplierId; // 中标供应商Id
    @TableField(value="win_supplier_name")
    private String winSupplierName; // 中标供应商名称
    @TableField(value="win_mny")
    private BigDecimal winMny; // 中标金额
    @TableField(value="win_reason")
    private String winReason; // 中标原因
    @TableField(value="create_name")
    private String createName; // 申请人

    @TableField(exist = false)
    @SubEntity(serviceName = "compareProductService",pidName = "compareId")
    private List<CompareProductEntity> compareProductEntities = new ArrayList<>(); // 通知物资清单实体
    @TableField(exist = false)
    @SubEntity(serviceName = "compareSupplierInfoService",pidName = "compareId")
    private List<CompareSupplierInfoEntity> compareSupplierInfoEntities = new ArrayList<>(); // 通知物资清单实体
    @TableField(exist = false)
    @SubEntity(serviceName = "compareSupplierTenderService",pidName = "compareId")
    private List<CompareSupplierTenderEntity> compareSupplierTenderEntities = new ArrayList<>(); // 通知物资清单实体



    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectSourceId() {
        return projectSourceId;
    }

    public void setProjectSourceId(String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    public Long getCropId() {
        return cropId;
    }

    public void setCropId(Long cropId) {
        this.cropId = cropId;
    }
    public String getCropName() {
        return cropName;
    }

    public void setCropName(String cropName) {
        this.cropName = cropName;
    }
    public String getCropSourceId() {
        return cropSourceId;
    }

    public void setCropSourceId(String cropSourceId) {
        this.cropSourceId = cropSourceId;
    }
    public Long getRealCorpId() {
        return realCorpId;
    }

    public void setRealCorpId(Long realCorpId) {
        this.realCorpId = realCorpId;
    }
    public String getRealNcCorp() {
        return realNcCorp;
    }

    public void setRealNcCorp(String realNcCorp) {
        this.realNcCorp = realNcCorp;
    }
    public String getRealCorpName() {
        return realCorpName;
    }

    public void setRealCorpName(String realCorpName) {
        this.realCorpName = realCorpName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgSourceId() {
        return orgSourceId;
    }

    public void setOrgSourceId(String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Date getSubmitDeadline() {
        return submitDeadline;
    }

    public void setSubmitDeadline(Date submitDeadline) {
        this.submitDeadline = submitDeadline;
    }
    public Date getCompareTime() {
        return compareTime;
    }

    public void setCompareTime(Date compareTime) {
        this.compareTime = compareTime;
    }
    public Long getSettingId() {
        return settingId;
    }

    public void setSettingId(Long settingId) {
        this.settingId = settingId;
    }
    public Long getTenderId() {
        return tenderId;
    }

    public void setTenderId(Long tenderId) {
        this.tenderId = tenderId;
    }
    public String getTenderNo() {
        return tenderNo;
    }

    public void setTenderNo(String tenderNo) {
        this.tenderNo = tenderNo;
    }
    public String getTenderName() {
        return tenderName;
    }

    public void setTenderName(String tenderName) {
        this.tenderName = tenderName;
    }
    public String getNotification() {
        return notification;
    }

    public void setNotification(String notification) {
        this.notification = notification;
    }
    public String getWinSupplierId() {
        return winSupplierId;
    }

    public void setWinSupplierId(String winSupplierId) {
        this.winSupplierId = winSupplierId;
    }
    public String getWinSupplierName() {
        return winSupplierName;
    }

    public void setWinSupplierName(String winSupplierName) {
        this.winSupplierName = winSupplierName;
    }
    public BigDecimal getWinMny() {
        return winMny;
    }

    public void setWinMny(BigDecimal winMny) {
        this.winMny = winMny;
    }
    public String getWinReason() {
        return winReason;
    }

    public void setWinReason(String winReason) {
        this.winReason = winReason;
    }
    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public List<CompareProductEntity> getCompareProductEntities() {
        return compareProductEntities;
    }

    public void setCompareProductEntities(List<CompareProductEntity> compareProductEntities) {
        this.compareProductEntities = compareProductEntities;
    }

    public List<CompareSupplierInfoEntity> getCompareSupplierInfoEntities() {
        return compareSupplierInfoEntities;
    }

    public void setCompareSupplierInfoEntities(List<CompareSupplierInfoEntity> compareSupplierInfoEntities) {
        this.compareSupplierInfoEntities = compareSupplierInfoEntities;
    }

    public List<CompareSupplierTenderEntity> getCompareSupplierTenderEntities() {
        return compareSupplierTenderEntities;
    }

    public void setCompareSupplierTenderEntities(List<CompareSupplierTenderEntity> compareSupplierTenderEntities) {
        this.compareSupplierTenderEntities = compareSupplierTenderEntities;
    }
}

==> cscec5b-ecxj-impl-3.0.0-20230509.073540-32-sources.jar: com/ejianc/business/ecxj/bean/CompareEntity.java <==
package com.ejianc.business.ecxj.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 比选报价
 * 
 * @author generator
 * 
 */
 @TableName("ejc_ecxj_compare")
public class CompareEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="notice_id")
    private Long noticeId; // 通知单Id
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_source_id")
    private String projectSourceId; // 项目来源id
    @TableField(value="crop_id")
    private Long cropId; // 项目所属组织id
    @TableField(value="crop_name")
    private String cropName; // 所属公司
    @TableField(value="crop_source_id")
    private String cropSourceId; // 项目所属组织来源id
    @TableField(value="real_corp_id")
    private Long realCorpId; // NC所属组织ID
    @TableField(value="real_nc_corp")
    private String realNcCorp; // NC所属组织PK
    @TableField(value="real_corp_name")
    private String realCorpName; // NC所属组织名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_source_id")
    private String orgSourceId; // 组织来源id
    @TableField(value="org_name")
    private String orgName; // 组织名称

    @TableField(value="material_type_id")
    private Long materialTypeId; // 材料类型Id
    @TableField(value="material_type_name")
    private String materialTypeName; // 材料类型名称

    @TableField(value="submit_deadline")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date submitDeadline; // 填报截止日期
    @TableField(value="compare_time")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date compareTime; // 比选时间

    @TableField(value="setting_id")
    private Long settingId; // 引用的设置类型Id
    @TableField(value="tender_id")
    private Long tenderId; // 云筑招标Id
    @TableField(value="tender_no")
    private String tenderNo; // 云筑招标编号
    @TableField(value="tender_name")
    private String tenderName; // 云筑招标名称

    @TableField(value="quote_type")
    private Integer quoteType; // 报价方式
    @TableField(value="compare_status")
    private Integer compareStatus; // 比价状态，0-正常，1-中标，2-流标
    @TableField(value="notification")
    private String notification; // 通知内容
    @TableField(value="create_name")
    private String createName; // 申请人

    @TableField(exist = false)
    @SubEntity(serviceName = "compareSupplierService",pidName = "compareId")
    private List<CompareSupplierEntity> compareSupplierEntities = new ArrayList<>(); // 通知物资清单实体
    @TableField(exist = false)
    @SubEntity(serviceName = "compareSupplierTenderService",pidName = "compareId")
    private List<CompareSupplierTenderEntity> compareSupplierTenderEntities = new ArrayList<>(); // 中标供应商信息



    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getNoticeId() {
        return noticeId;
    }

    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectSourceId() {
        return projectSourceId;
    }

    public void setProjectSourceId(String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    public Long getCropId() {
        return cropId;
    }

    public void setCropId(Long cropId) {
        this.cropId = cropId;
    }
    public String getCropName() {
        return cropName;
    }

    public void setCropName(String cropName) {
        this.cropName = cropName;
    }
    public String getCropSourceId() {
        return cropSourceId;
    }

    public void setCropSourceId(String cropSourceId) {
        this.cropSourceId = cropSourceId;
    }
    public Long getRealCorpId() {
        return realCorpId;
    }

    public void setRealCorpId(Long realCorpId) {
        this.realCorpId = realCorpId;
    }
    public String getRealNcCorp() {
        return realNcCorp;
    }

    public void setRealNcCorp(String realNcCorp) {
        this.realNcCorp = realNcCorp;
    }
    public String getRealCorpName() {
        return realCorpName;
    }

    public void setRealCorpName(String realCorpName) {
        this.realCorpName = realCorpName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgSourceId() {
        return orgSourceId;
    }

    public void setOrgSourceId(String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Date getSubmitDeadline() {
        return submitDeadline;
    }

    public void setSubmitDeadline(Date submitDeadline) {
        this.submitDeadline = submitDeadline;
    }
    public Date getCompareTime() {
        return compareTime;
    }

    public void setCompareTime(Date compareTime) {
        this.compareTime = compareTime;
    }
    public Long getSettingId() {
        return settingId;
    }

    public void setSettingId(Long settingId) {
        this.settingId = settingId;
    }
    public Long getTenderId() {
        return tenderId;
    }

    public void setTenderId(Long tenderId) {
        this.tenderId = tenderId;
    }
    public String getTenderNo() {
        return tenderNo;
    }

    public void setTenderNo(String tenderNo) {
        this.tenderNo = tenderNo;
    }
    public String getTenderName() {
        return tenderName;
    }

    public void setTenderName(String tenderName) {
        this.tenderName = tenderName;
    }
    public Integer getQuoteType() {
        return quoteType;
    }

    public void setQuoteType(Integer quoteType) {
        this.quoteType = quoteType;
    }
    public Integer getCompareStatus() {
        return compareStatus;
    }

    public void setCompareStatus(Integer compareStatus) {
        this.compareStatus = compareStatus;
    }
    public String getNotification() {
        return notification;
    }

    public void setNotification(String notification) {
        this.notification = notification;
    }
    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public List<CompareSupplierEntity> getCompareSupplierEntities() {
        return compareSupplierEntities;
    }

    public void setCompareSupplierEntities(List<CompareSupplierEntity> compareSupplierEntities) {
        this.compareSupplierEntities = compareSupplierEntities;
    }

    public List<CompareSupplierTenderEntity> getCompareSupplierTenderEntities() {
        return compareSupplierTenderEntities;
    }

    public void setCompareSupplierTenderEntities(List<CompareSupplierTenderEntity> compareSupplierTenderEntities) {
        this.compareSupplierTenderEntities = compareSupplierTenderEntities;
    }
}
